@@ -1,5 +1,6 @@
 import json
 from django.db import models
+from django.conf import settings
 from django.utils.six import with_metaclass
 from django.utils.translation import ugettext_lazy as _
 from . import SirTrevorContent
@@ -21,3 +22,8 @@ class SirTrevorField(with_metaclass(models.SubfieldBase, models.Field)):
 
     def to_python(self, value):
         return SirTrevorContent(value)
+
+
+if 'south' in settings.INSTALLED_APPS:
+    from south.modelsinspector import add_introspection_rules
+    add_introspection_rules([], ["^sirtrevor\.fields\.SirTrevorField"])
